@@ -10,7 +10,7 @@ from collections import namedtuple
 from enum import Enum
 from typing import List
 
-version = '3.0.59'
+version = '3.0.62'
 version_info = list(map(int, version.split('.')))
 
 
@@ -57,7 +57,7 @@ class ComponentType():
     Sanic = "Sanic"
     AioHttp = "AioHttp"
     Pyramid = "Pyramid"
-    User = "User"
+    CustomLog = "CustomLog"
     Log = "Log"
 
 
