@@ -99,10 +99,11 @@ def install():
         elif reader_type == ReaderType.QueryString:
             # import json
             # raw = request.stream.read()
-            # raw_json = request.bounded_stream.read()
-            # from urllib import parse
-            # params = parse.parse_qsl(raw_json)
-            code = request.params.get(reader.get("ReaderKey"), "")
+            raw_json = request.bounded_stream.read()
+            from urllib import parse
+            params = parse.parse_qsl(raw_json)
+            if request.method == "GET":
+                code = request.params.get(reader.get("ReaderKey"), "")
         elif reader_type == ReaderType.Environment:
             import os
 
