@@ -33,7 +33,9 @@ def log(text, *args, level=1):
     :return:
     """
     startup_debug = os.environ.get("FAST_DEBUG", "off").lower() in ("on", "true", "1")
+    print("FAST_DEBUG:", startup_debug)
     debug_level = int(os.environ.get('FAST_DEBUG_LEVEL', 0))
+    print("FAST_DEBUG_LEVEL:", debug_level)
     if startup_debug:
         if debug_level >= level:
             text = text % args
